/*
 *	cook - file construction tool
 *	Copyright (C) 1994, 1997 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for cook/fngrprnt_lex.c
 */

#ifndef COOK_FNGRPRNT_LEX_H
#define COOK_FNGRPRNT_LEX_H

#include <main.h>

void fngrprnt_lex_open _((char *));
void fngrprnt_lex_close _((void));
int fngrprnt_lex _((void));
void fngrprnt_error _((char *)); /* i18n keyword */

#endif /* COOK_FNGRPRNT_LEX_H */
